@@ -1,7 +1,7 @@
 import os
 
-user_dir = os.path.expanduser("~") # the homedir
-#user_dir = "/home/user/"                   # debug
+#user_dir = os.path.expanduser("~") # the homedir
+user_dir = "/home/user/"                   # debug
 config_dir = os.path.join(user_dir,".nqaap/")
 book_dir = os.path.join(user_dir,"MyDocs/Audiobooks/")
 
